From 006d1f90dda3ff2b678ebd04d579ddbbca42ffaf 2011-11-26 21:34:22
From: Thomas Kluyver <takowl@gmail.com>
Date: 2011-11-26 21:34:22
Subject: [PATCH] Correct links to issues by Sphinx github extension.

---

diff --git a/docs/sphinxext/github.py b/docs/sphinxext/github.py
index 726f029..d6215e6 100644
--- a/docs/sphinxext/github.py
+++ b/docs/sphinxext/github.py
@@ -25,7 +25,7 @@ def make_link_node(rawtext, app, type, slug, options):
 
     :param rawtext: Text being replaced with link node.
     :param app: Sphinx application context
     :param type: Link type (issue, changeset, etc.)
     :param slug: ID of the thing to link to
     :param options: Options dictionary passed to role func.
     """
@@ -79,7 +79,7 @@ def ghissue_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
     if 'pull' in name.lower():
         category = 'pull'
     elif 'issue' in name.lower():
-        category = 'issue'
+        category = 'issues'
     else:
         msg = inliner.reporter.error(
             'GitHub roles include "ghpull" and "ghissue", '
@@ -25,7 +25,7 @@ def make_link_node(rawtext, app, type, slug, options):
     :param rawtext: Text being replaced with link node.
     :param app: Sphinx application context
-    :param type: Link type (issue, changeset, etc.)
+    :param type: Link type (issues, changeset, etc.)
     :param slug: ID of the thing to link to
     :param options: Options dictionary passed to role func.